@@ -1,4 +1,4 @@
-# Copyright 2017 Facundo Batista, Nicolás Demarchi
+# Copyright 2017-2022 Facundo Batista, Nicolás Demarchi
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -18,10 +18,11 @@
 
 import io
 import logging
-import docutils.core
-import pep257
-import rst2html5_
+from unittest.mock import patch
 
+import docutils.core
+import pydocstyle
+import rst2html5_
 from flake8.api.legacy import get_style_guide
 from pyuca import Collator
 
@@ -32,33 +33,32 @@ FLAKE8_OPTIONS = {'max_line_length': 99, 'select': ['E', 'W', 'F', 'C', 'N']}
 PEP257_ROOTS = ['fades']
 
 # avoid seeing all DEBUG logs if the test fails
-pep257.log.setLevel(logging.WARNING)
 for logger_name in ('flake8.plugins', 'flake8.api', 'flake8.checker', 'flake8.main'):
     logging.getLogger(logger_name).setLevel(logging.CRITICAL)
 
 
-def test_flake8_pytest(mocker):
+def test_flake8_pytest():
     python_filepaths = get_python_filepaths(FLAKE8_ROOTS)
     style_guide = get_style_guide(**FLAKE8_OPTIONS)
     fake_stdout = io.StringIO()
-    mocker.patch('sys.stdout', fake_stdout)
-    report = style_guide.check_files(python_filepaths)
+    with patch('sys.stdout', fake_stdout):
+        report = style_guide.check_files(python_filepaths)
     assert report.total_errors == 0, "There are issues!\n" + fake_stdout.getvalue()
 
 
 def test_pep257_pytest():
     python_filepaths = get_python_filepaths(PEP257_ROOTS)
-    result = list(pep257.check(python_filepaths))
+    result = list(pydocstyle.check(python_filepaths))
     assert len(result) == 0, "There are issues!\n" + '\n'.join(map(str, result))
 
 
-def test_readme_sanity(mocker):
+def test_readme_sanity():
     fake_stdout = io.StringIO()  # just to ignore the output
     fake_stderr = io.StringIO()  # will have content if there are problems
     with open('README.rst', 'rt', encoding='utf8') as fh:
-        mocker.patch('sys.stdout', fake_stdout)
-        mocker.patch('sys.stderr', fake_stderr)
-        docutils.core.publish_file(source=fh, writer=rst2html5_.HTML5Writer())
+        with patch('sys.stdout', fake_stdout):
+            with patch('sys.stderr', fake_stderr):
+                docutils.core.publish_file(source=fh, writer=rst2html5_.HTML5Writer())
 
     errors = fake_stderr.getvalue()
     assert not bool(errors), "There are issues!\n" + errors
