@@ -18,24 +18,24 @@
 from fades.logger import set_up as log_set_up
 
 
-def test_salutes_info(logged):
+def test_salutes_info(logs):
     """Check saluting handler."""
     logger = log_set_up(verbose=False, quiet=True)
     logger.warning("test foobar")
 
-    logged.assert_info("Hi! This is fades")
-    logged.assert_warning("test foobar")
+    assert "Hi! This is fades" in logs.info
+    assert "test foobar" in logs.warning
 
 
-def test_salutes_once(logged):
+def test_salutes_once(logs):
     logger = log_set_up(verbose=False, quiet=False)
     logger.info("test foobar")
-    logged.assert_info("Hi! This is fades")
-    logged.assert_info("test foobar")
+    assert "Hi! This is fades" in logs.info
+    assert "test foobar" in logs.info
 
     # again, check this time it didn't salute, but original log message is ok
-    logged.records = []
+    logs.reset()
     logger.info("test barbarroja")
 
-    logged.assert_not_info("Hi! This is fades")
-    logged.assert_info("test barbarroja")
+    assert "Hi! This is fades" not in logs.info
+    assert "test barbarroja" in logs.info
